""" Python XML Templating Language

    Modules in this package:

    reference   - reference implementation
    optimised   - optimised implementation (not yet written)
    constants   - constants shared across all modules
    exceptions  - exceptions that may be raised by an implementation
    serialisers - write DOM trees in various formats
    utilities   - general-purpose helper functions
    pxdom       - stand-alone pure-Python DOM L3 Core/XML/Load/Save imp
    fixdom      - bug-fix wrappers to other DOM imps

    Other files in this package:

    __error__   - PXTL template to pretty-print a PXTL error

    Functions provided at pxtl module level:

    processDocument - forwarded to PXTL implementation

    Example usage:

    import pxtl
    g= { 'itemsToShow': 3 }
    pxtl.processDocument(os.path.join(templateDir, 'items.px'), globals= g)

    Other functions may be available directly from the implementation module,
    eg. pxtl.reference.
"""

__version__= 0,8
__author__ = 'Andrew Clover <and@doxdesk.com>'
__date__   = '24 July 2003'

__all__= [
  'reference', 'optimised',
  'constants', 'exceptions',
  'serialisers', 'utilities',
  'pxdom', 'fixdom',
  'processFile'
]


def processFile(
  path, writer= None, globals= None, debug= (0==1), headers= (0==1),
  dom= None, bytecodebase= None
):
  """ Use the most appropriate PXTL implementation available to load a file,
      transform it, and send the serialised output to a stream. Currently this
      always calls the reference implementation; future versions are likely
      to call the optimised implementation by default. If you wish always to
      use a known implementation, import that module (pxtl.reference or
      pxtl.optimised) and call processDocument on it directly.

      writer  - stream-like object to send serialised output (default stdout)
      globals - dictionary to use as template global scope (default {})
      debug   - output a debugging page if there's an error (default False)
      headers - output HTTP response headers (for CGI scripts, default False)
      dom     - DOM L3 Core/XML/Load implementation to use (default pxdom)
      bytecodebase - TBC, to be used by optimised implementation to store
                cached compiled bytecode files.
  """
  import pxtl.reference
  pxtl.reference.processFile(path, writer, globals, debug, headers, dom)
